<?php

/**
 * @file
 * Contains \Drupal\uniplace_installer\Plugin\Block\UniplaceLinksBlock.
 */

namespace Drupal\uniplace_installer\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'UniplaceLinksBlock' Block
 *
 * @Block(
 *   id = "uniplace_links_block",
 *   admin_label = @Translation("Uniplace Links Block"),
 * )
 */
class UniplaceLinksBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
  
    $markup = self::getMarkup();
    
    /*
     * должны быть корректные html-сущности, 
     * иначе Xss::filter() преабразует в &amp; и не вернет обратно:
     * // Change back only well-formed entities in our whitelist:
     * // Decimal numeric entities.
     * $string = preg_replace('/&amp;#([0-9]+;)/', '&#\1', $string);
     */
    $correctHtmlEntities = preg_replace('/&#([0-9]+)/', '&#\1;', $markup);
    
    // '!--' - разрешить вывод html-комментариев
    // для вывода <!--d4206___-->
    $block = [
      '#allowed_tags' => array('a', 'br', '!--', 'em', 'strong', 'cite', 'blockquote', 'code', 'ul', 'ol', 'li', 'dl', 'dt', 'dd'),
      '#markup' => $correctHtmlEntities
    ];
    return $block;
  }
  
  /**
   * сюда перенесен, с небольшими изменениями, код показа ссылок
   * добавлена обработка подключения:
   * не упадет в Fatal Error при отсутствии папки/файлов
   * 
   * @return string
   */
  public static function getMarkup() {
    @include_once($_SERVER["DOCUMENT_ROOT"] . "/uniplacer_config.php");
    @include_once($_SERVER["DOCUMENT_ROOT"] . "/" . _UNIPLACE_USER_ . "/uniplacer.php"); 

    $res = '';
    
    if (class_exists('Uniplacer') && defined('_UNIPLACE_USER_')) {
      $Uniplacer = new \Uniplacer(_UNIPLACE_USER_);
      $res .= $Uniplacer->GetCode(true);
      $links = $Uniplacer->GetLinks();

      if ($links) {
        foreach ($links as $link) {
          $res .=  $link.'<br>';
        }
      }
    }
    
    return $res;
  }

}
